@@ -31,7 +31,10 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.splk_dsm_power", "trackme_rest_api_splk_dsm_power.log"
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 # import rest handler
@@ -68,9 +71,9 @@ from trackme_libs_bulk_edit import post_bulk_edit, generic_batch_update
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkDsm_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkDsmWrite_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkDsm_v2, self).__init__(
+        super(TrackMeHandlerSplkDsmWrite_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -118,7 +121,7 @@ class TrackMeHandlerSplkDsm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -232,7 +235,7 @@ class TrackMeHandlerSplkDsm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -353,7 +356,7 @@ class TrackMeHandlerSplkDsm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -478,7 +481,7 @@ class TrackMeHandlerSplkDsm_v2(trackme_rest_handler.RESTHandler):
                 try:
                     future_tolerance = resp_dict["future_tolerance"]
                 except Exception as e:
-                    future_tolerance = "system"
+                    future_tolerance = None
 
         else:
             # body is required in this endpoint, if not submitted describe the usage
@@ -522,7 +525,7 @@ class TrackMeHandlerSplkDsm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -674,7 +677,7 @@ class TrackMeHandlerSplkDsm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -795,7 +798,7 @@ class TrackMeHandlerSplkDsm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -911,7 +914,7 @@ class TrackMeHandlerSplkDsm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1042,7 +1045,7 @@ class TrackMeHandlerSplkDsm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1322,7 +1325,7 @@ class TrackMeHandlerSplkDsm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1820,7 +1823,7 @@ class TrackMeHandlerSplkDsm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -1981,7 +1984,7 @@ class TrackMeHandlerSplkDsm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -2208,7 +2211,7 @@ class TrackMeHandlerSplkDsm_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
