@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -74,7 +74,7 @@ class TrackMeSplkCmdb(GeneratingCommand):
         **Syntax:** **component=****
         **Description:** The TrackMe component""",
         require=True,
-        validate=validators.Match("component", r"^(?:dsm|dhm|mhm|flx|fqm|wlk)$"),
+        validate=validators.Match("component", r"^(?:dsm|dhm|mhm|cim|flx|fqm|wlk)$"),
     )
 
     tenant_id = Option(
@@ -135,6 +135,7 @@ class TrackMeSplkCmdb(GeneratingCommand):
             "dsm": "splk_general_dsm_cmdb_search",
             "dhm": "splk_general_dhm_cmdb_search",
             "mhm": "splk_general_mhm_cmdb_search",
+            "cim": "splk_general_cim_cmdb_search",
             "flx": "splk_general_flx_cmdb_search",
             "fqm": "splk_general_fqm_cmdb_search",
             "wlk": "splk_general_wlk_cmdb_search",
@@ -143,6 +144,7 @@ class TrackMeSplkCmdb(GeneratingCommand):
             "dsm": f"kv_trackme_dsm_tenant_{self.tenant_id}",
             "dhm": f"kv_trackme_dhm_tenant_{self.tenant_id}",
             "mhm": f"kv_trackme_mhm_tenant_{self.tenant_id}",
+            "cim": f"kv_trackme_cim_tenant_{self.tenant_id}",
             "flx": f"kv_trackme_flx_tenant_{self.tenant_id}",
             "fqm": f"kv_trackme_fqm_tenant_{self.tenant_id}",
             "wlk": f"kv_trackme_wlk_tenant_{self.tenant_id}",
